DexcomAppIds class

Class for managing and retrieving app IDs.

Constructors

DexcomAppIds({String? us, String? ous, String? jp})
It is recommended to provide at least US and Japanese app IDs. At least one app ID is required.

Properties

hashCode int
The hash code for this object.
no setterinherited
jp String?
Japanese app ID.
getter/setter pair
ous String?
Out-of-US app ID.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
us String?
US app ID.
getter/setter pair

Methods

get({DexcomRegion? code}) String
Get the requested app ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, String?>
Return a Map<String, String?> of this object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited