DexcomAuthorizationException class

Thrown when an error occurs during Dexcom account authentication.

Implemented types

Constructors

DexcomAuthorizationException(String? message)
Thrown when an error occurs during Dexcom account authentication.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
Message of the exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Converts the exception to a string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited