DexcomInitializationError class

Thrown when an error occurs intializing a Dexcom or a DexcomStreamProvider.

Implemented types

Constructors

DexcomInitializationError(String? message)
Thrown when an error occurs intializing a Dexcom or a DexcomStreamProvider.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
Message of the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
Stack trace of the error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Converts the error to a string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited