dexcom library
Library that uses the Dexcom Share API.
Classes
- Dexcom
- Main class that controls all of the functions.
- DexcomAppIds
- Class for managing and retrieving app IDs.
- DexcomGlucoseRequest
- An object representing a web request made to Dexcom's servers for glucose data retrieval.
- DexcomReading
- An individual Dexcom CGM reading.
- DexcomStreamProvider
- Class that provides a stream that you can listen to. This will automatically fetch new readings when the old readings have hit the interval (defaults to 300 seconds).
- DexcomVerificationResult
- Used when verifying a user's credentials.
Enums
- DexcomGlucoseUnit
- The unit used for reading calculation.
- DexcomRegion
- Identifiers for regions that Dexcom uses. This is used in both the Share API and the Web API.
- DexcomTrend
- The trend of a Dexcom reading.
- DexcomUpdateStatus
- The status of the current Dexcom object.
Extensions
- DexcomTrendExtension on DexcomTrend
- Provides extra functions for a DexcomTrend.
Exceptions / Errors
- DexcomAuthorizationException
- Thrown when an error occurs during Dexcom account authentication.
- DexcomGlucoseRetrievalException
- Thrown when an error occurs during Dexcom glucose retrieval.
- DexcomInitializationError
- Thrown when an error occurs intializing a Dexcom or a DexcomStreamProvider.