DexcomAuthorizationException class
Thrown when an error occurs during Dexcom account authentication.
- Implemented types
Constructors
- DexcomAuthorizationException(String? message)
- Thrown when an error occurs during Dexcom account authentication.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Converts the exception to a string.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited