DexcomGlucoseRetrievalException class
Thrown when an error occurs during Dexcom glucose retrieval.
- Implemented types
Constructors
- DexcomGlucoseRetrievalException(String? message, int code, DexcomGlucoseRequest request)
- Thrown when an error occurs during Dexcom glucose retrieval.
Properties
- code → int
-
Status code of the exception. This will be either HTTP status code, or
-1if it's not related to HTTP.final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
Message of the exception.
final
- request → DexcomGlucoseRequest
-
The DexcomGlucoseRequest object that represents the request made to Dexcom.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Converts the exception to a string.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited