DexcomReading class
An individual Dexcom CGM reading.
Constructors
- DexcomReading({required DateTime systemTime, required DateTime displayTime, required num mgdL, required DexcomTrend trend, required DexcomGlucoseUnit unit})
- An individual Dexcom CGM reading.
-
DexcomReading.fromJson(Map<
String, dynamic> input) -
Get a DexcomReading from a
Map<String, dynamic>.factory
Properties
- displayTime → DateTime
-
displayTime is the time being shown on the device to the user.
Depending on the device, this time may be user-configurable, and can therefore change its offset relative to systemTime.
Note that systemTime is not "true" UTC time because of drift and/or user manipulation of the devices' clock.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mgdL → num
-
Blood glucose level. This is always mg/dL.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemTime → DateTime
-
systemTime is the UTC time according to the device.
final
- trend → DexcomTrend
-
Trend of the current glucose.
final
- value → num
-
The glucose value in your chosen DexcomGlucoseUnit unit.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert the reading to JSON.
-
toString(
) → String -
Convert the reading to a string.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited