DexcomTrend enum
The trend of a Dexcom reading.
- Inheritance
- Available extensions
Values
- flat → const DexcomTrend
-
Steady
- fortyFiveDown → const DexcomTrend
-
Slowly falling (-1/minute)
- fortyFiveUp → const DexcomTrend
-
Slowly rising (+1/minute)
- singleDown → const DexcomTrend
-
Falling (-2/minute)
- singleUp → const DexcomTrend
-
Rising (+2/minute)
- doubleDown → const DexcomTrend
-
Quickly falling (-3/minute)
- doubleUp → const DexcomTrend
-
Quickly rising (+3/minute)
- none → const DexcomTrend
-
No trend
- nonComputable → const DexcomTrend
-
The graph is too wonky for Dexcom to know which way the glucose levels are going. You can try to compute it yourself if you want to.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convert(
[DexcomTrend? trend]) → String -
Available on DexcomTrend, provided by the DexcomTrendExtension extension
Convert a DexcomTrend to a string. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stringify(
) → String -
Available on DexcomTrend, provided by the DexcomTrendExtension extension
Convert a DexcomTrend to a string. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DexcomTrend> - A constant List of the values in this enum, in order of their declaration.