DexcomVerificationResult class
Used when verifying a user's credentials.
Constructors
- DexcomVerificationResult(bool status, [Object? error])
-
Status is required.
const
Properties
- error → Object?
-
The potential error returned from the result.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → bool
-
If true, then user verified. If false, then not verified.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Turn this object into a
Map<String, Object?>, containing status and error. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited